@@ -1,26 +1,31 @@
 import logging
-import logging
-from typing import Dict, List, Iterable, Tuple, Any
+import pathlib
+from typing import Any
 from typing import Dict, Tuple, List
 
 from allennlp.common.file_utils import cached_path
+from allennlp.data import Vocabulary
 from allennlp.data.dataset_readers.dataset_reader import DatasetReader
 from allennlp.data.fields import Field, TextField, SequenceLabelField, MetadataField
 from allennlp.data.instance import Instance
 from allennlp.data.token_indexers import (
     TokenIndexer,
     PretrainedTransformerIndexer,
-    PretrainedTransformerMismatchedIndexer,
 )
 from allennlp.data.tokenizers import Token
-from allennlp_models.common.ontonotes import Ontonotes, OntonotesSentence
+from allennlp_models.common.ontonotes import Ontonotes
 from allennlp_models.structured_prediction import SrlReader
 from conllu import parse_incr
 from overrides import overrides
 from transformers import AutoTokenizer
 
+from transformer_srl.utils import load_label_list
+
 logger = logging.getLogger(__name__)
 
+FRAME_LIST_PATH = pathlib.Path(__file__).resolve().parent / "resources" / "framelist.txt"
+
+
 """
 ID: Word index, integer starting at 1 for each new sentence; may be a range for tokens with multiple words.
 FORM: Word form or punctuation symbol.
@@ -50,6 +55,25 @@ conllu_fields = [
 ]
 
 
+conll2009_fields = [
+    "id",
+    "form",
+    "lemma",
+    "plemma",
+    "pos",
+    "ppos",
+    "feat",
+    "pfeat",
+    "head",
+    "phead",
+    "deprel",
+    "pdeprel",
+    "fillpred",
+    "frame",
+    "roles",
+]
+
+
 def _convert_verb_indices_to_wordpiece_indices(
     verb_indices: List[int], offsets: List[int], binary: bool = True
 ):
@@ -166,7 +190,6 @@ class SrlTransformersSpanReader(SrlReader):
             "tokens": PretrainedTransformerIndexer(model_name)
         }
         self._domain_identifier = domain_identifier
-
         self.tokenizer = AutoTokenizer.from_pretrained(model_name)
         self.lowercase_input = "uncased" in model_name
 
@@ -234,19 +257,26 @@ class SrlTransformersSpanReader(SrlReader):
                 self._domain_identifier,
             )
 
-        for sentence in self._ontonotes_subset(
-            ontonotes_reader, file_path, self._domain_identifier
-        ):
-            tokens = [Token(t) for t in sentence.words]
-            if sentence.srl_frames:
-                for (_, tags) in sentence.srl_frames:
-                    verb_indicator = [1 if label[-2:] == "-V" else 0 for label in tags]
-                    frames = self._get_predicate_labels(sentence, verb_indicator)
-                    lemmas = [
-                        f for f, v in zip(sentence.predicate_lemmas, verb_indicator) if v == 1
-                    ]
-                    if not all(v == 0 for v in verb_indicator):
-                        yield self.text_to_instance(tokens, verb_indicator, frames, lemmas, tags)
+        counter = 0
+        try:
+            for sentence in self._ontonotes_subset(
+                ontonotes_reader, file_path, self._domain_identifier
+            ):
+                tokens = [Token(t) for t in sentence.words]
+                if sentence.srl_frames:
+                    for (_, tags) in sentence.srl_frames:
+                        verb_indicator = [1 if label[-2:] == "-V" else 0 for label in tags]
+                        frames = self._get_predicate_labels(sentence, verb_indicator)
+                        lemmas = [
+                            f for f, v in zip(sentence.predicate_lemmas, verb_indicator) if v == 1
+                        ]
+                        if not all(v == 0 for v in verb_indicator):
+                            yield self.text_to_instance(
+                                tokens, verb_indicator, frames, lemmas, tags
+                            )
+                counter += 1
+        except:
+            print("COUNTER", counter)
 
     def text_to_instance(  # type: ignore
         self,
@@ -355,16 +385,22 @@ class SrlTransformersSpanReader(SrlReader):
 
     def _get_predicate_labels(self, sentence, verb_indicator):
         labels = []
-        for i, v in enumerate(verb_indicator):
-            if v == 1:
-                label = (
-                    "{}.{}".format(sentence.predicate_lemmas[i], sentence.predicate_framenet_ids[i])
-                    if sentence.predicate_framenet_ids[i].isdigit()
-                    else sentence.predicate_framenet_ids[i]
-                )
-                labels.append(label)
-            else:
-                labels.append("O")
+        try:
+            for i, v in enumerate(verb_indicator):
+                if v == 1:
+                    label = (
+                        "{}.{}".format(
+                            sentence.predicate_lemmas[i], sentence.predicate_framenet_ids[i]
+                        )
+                        if sentence.predicate_framenet_ids[i].isdigit()
+                        else sentence.predicate_framenet_ids[i]
+                    )
+                    labels.append(label)
+                else:
+                    labels.append("O")
+        except:
+            print(sentence.words)
+            print(sentence.predicate_framenet_ids)
         return labels
 
 
@@ -386,20 +422,25 @@ class SrlUdpDatasetReader(SrlTransformersSpanReader):
     """
 
     def __init__(
-        self, token_indexers: Dict[str, TokenIndexer] = None, model_name: str = None, **kwargs,
+        self,
+        token_indexers: Dict[str, TokenIndexer] = None,
+        model_name: str = None,
+        format: str = None,
+        **kwargs,
     ) -> None:
         super().__init__(token_indexers=token_indexers, model_name=model_name, **kwargs)
+        self.format = format
 
     @overrides
     def _read(self, file_path: str):
         # if `file_path` is a URL, redirect to the cache
         file_path = cached_path(file_path)
-        with open(file_path, "r") as conllu_file:
-            logger.info("Reading UD instances from conllu dataset at: %s", file_path)
+        with open(file_path, "r") as conll_file:
+            logger.info("Reading instances from dataset at: %s", file_path)
 
             for annotation in parse_incr(
-                conllu_file,
-                fields=conllu_fields,
+                conll_file,
+                fields=conllu_fields if self.format == "conllu" else conll2009_fields,
                 field_parsers={"roles": lambda line, i: line[i:]},
             ):
                 # CoNLLU annotations sometimes add back in words that have been elided
