@@ -1,6 +1,4 @@
-import os
 import pathlib
-from collections import defaultdict
 from typing import Dict, List, Any, Union
 
 import numpy as np
@@ -9,11 +7,7 @@ import torch.nn.functional as F
 from allennlp.data import TextFieldTensors, Vocabulary
 from allennlp.models.model import Model
 from allennlp.nn import InitializerApplicator, util
-from allennlp.nn.util import (
-    get_lengths_from_binary_sequence_mask,
-    viterbi_decode,
-    get_device_of,
-)
+from allennlp.nn.util import get_device_of
 from allennlp.nn.util import get_text_field_mask, sequence_cross_entropy_with_logits
 from allennlp.training.metrics.fbeta_measure import FBetaMeasure
 from allennlp_models.structured_prediction import SrlBert
@@ -21,15 +15,15 @@ from allennlp_models.structured_prediction.metrics.srl_eval_scorer import (
     DEFAULT_SRL_EVAL_PATH,
     SrlEvalScorer,
 )
-from allennlp.modules.token_embedders import PretrainedTransformerMismatchedEmbedder
 from overrides import overrides
 from torch.nn.modules import Linear, Dropout
 from transformers import AutoModel
 
-from transformer_srl.utils import load_lemma_frame, load_role_frame
+from transformer_srl.utils import load_lemma_frame, load_role_frame, load_label_list
 
 LEMMA_FRAME_PATH = pathlib.Path(__file__).resolve().parent / "resources" / "lemma2frame.csv"
 FRAME_ROLE_PATH = pathlib.Path(__file__).resolve().parent / "resources" / "frame2role.csv"
+FRAME_LIST_PATH = pathlib.Path(__file__).resolve().parent / "resources" / "framelist.txt"
 
 
 @Model.register("transformer_srl_dependency")
@@ -337,10 +331,13 @@ class TransformerSrlSpan(SrlBert):
         self.restrict_roles = restrict_roles
 
         if isinstance(bert_model, str):
-            self.bert_model = AutoModel.from_pretrained(bert_model)
+            self.transformer = AutoModel.from_pretrained(bert_model)
         else:
-            self.bert_model = bert_model
+            self.transformer = bert_model
         self.frame_criterion = torch.nn.CrossEntropyLoss()
+        # add missing labels
+        frame_list = load_label_list(FRAME_LIST_PATH)
+        # self.vocab.add_tokens_to_namespace(frame_list, "frames_labels")
         self.num_classes = self.vocab.get_vocab_size("labels")
         self.frame_num_classes = self.vocab.get_vocab_size("frames_labels")
         if srl_eval_path is not None:
@@ -350,9 +347,9 @@ class TransformerSrlSpan(SrlBert):
         else:
             self.span_metric = None
         self.f1_frame_metric = FBetaMeasure(average="micro")
-        self.tag_projection_layer = Linear(self.bert_model.config.hidden_size, self.num_classes)
+        self.tag_projection_layer = Linear(self.transformer.config.hidden_size, self.num_classes)
         self.frame_projection_layer = Linear(
-            self.bert_model.config.hidden_size, self.frame_num_classes
+            self.transformer.config.hidden_size, self.frame_num_classes
         )
         self.embedding_dropout = Dropout(p=embedding_dropout)
         self._label_smoothing = label_smoothing
@@ -408,7 +405,8 @@ class TransformerSrlSpan(SrlBert):
             A scalar loss to be optimised.
         """
         mask = get_text_field_mask(tokens)
-        bert_embeddings, _ = self.bert_model(
+        # token_type_ids = torch.zeros_like(verb_indicator)
+        bert_embeddings, _ = self.transformer(
             input_ids=util.get_token_ids_from_text_field_tensors(tokens),
             token_type_ids=verb_indicator,
             attention_mask=mask,
@@ -460,9 +458,7 @@ class TransformerSrlSpan(SrlBert):
                 ]
                 batch_sentences = [example_metadata["words"] for example_metadata in metadata]
                 # Get the BIO tags from make_output_human_readable()
-                batch_bio_predicted_tags = self.make_output_human_readable(output_dict, False).pop(
-                    "tags"
-                )
+                batch_bio_predicted_tags = self.make_output_human_readable(output_dict).pop("tags")
                 from allennlp_models.structured_prediction.models.srl import (
                     convert_bio_tags_to_conll_format,
                 )
@@ -568,9 +564,13 @@ class TransformerSrlSpan(SrlBert):
             # This can be a lot of metrics, as there are 3 per class.
             # we only really care about the overall metrics, so we filter for them here.
             metric_dict_filtered = {
-                x.split("-")[0] + "_role": y for x, y in metric_dict.items() if "overall" in x
+                x.split("-")[0] + "_role": y
+                for x, y in metric_dict.items()
+                if "overall" in x and "f1" in x
+            }
+            frame_metric_dict = {
+                x + "_frame": y for x, y in frame_metric_dict.items() if "fscore" in x
             }
-            frame_metric_dict = {x + "_frame": y for x, y in frame_metric_dict.items()}
             return {**metric_dict_filtered, **frame_metric_dict}
 
     def _get_label_tokens(self, namespace: str = "labels"):
